# siggi 
[![Build Status](https://travis-ci.org/jbkalmbach/siggi.svg?branch=master)](https://travis-ci.org/jbkalmbach/siggi)
[![codecov.io](https://codecov.io/github/jbkalmbach/siggi/coverage.svg?branch=master)](https://codecov.io/github/jbkalmbach/siggi?branch=master)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)

Spectra Information Gain (SIGgi)
